<?php
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

// Get API Key status
$api_key = rank_get_api_key(); // Use renamed function
$is_api_key_set = ! empty( $api_key );

// Get health check categories
$health_check_categories = rank_get_health_check_categories(); // Use renamed function

// Determine the current tab
$current_tab = isset( $_GET['tab'] ) ? sanitize_key( $_GET['tab'] ) : 'bulk_fix'; // Default to 'bulk_fix'

// We'll let WordPress handle the wrap div and notices
// But we need to output our own H1 tag with the SVG icon

?>
<div class="wrap" data-api-key-set="<?php echo $is_api_key_set ? 'yes' : 'no'; ?>">
    <h1 style="display:none;" class="wp-heading-inline"><?php echo get_admin_page_title(); ?></h1>
    <?php
    // This is where WordPress will automatically insert notices ABOVE our H1
    // because the notices hooks run before our page content
    ?>
    <div style="display: flex; align-items: center; gap: 10px; margin-bottom: 1em;">
        <svg fill="currentColor" class="overflow-visible" xmlns="http://www.w3.org/2000/svg" width="100%" height="100%" viewBox="0 0 16 16" style="width: 1.5em; height: 2.5em; flex-shrink: 0;padding-top:2px;"><g transform="translate(-4)"><g transform="translate(4)"><path d="M8,0a8,8,0,1,0,8,8A8.009,8.009,0,0,0,8,0ZM7.726,15.053a6.206,6.206,0,1,1,6.206-6.206A6.206,6.206,0,0,1,7.726,15.053Z"></path><circle cx="3.414" cy="3.414" r="3.414" transform="translate(5.533 5.084)"></circle></g></g></svg>
        <h1>RANK AI by Morningscore</h1>
    </div>

<?php // --- Tab Navigation --- ?>
<h2 class="nav-tab-wrapper">
    <a href="?page=<?php echo esc_attr( $_REQUEST['page'] ); ?>&tab=bulk_fix" class="nav-tab <?php echo $current_tab === 'bulk_fix' ? 'nav-tab-active' : ''; ?>">
    ❤️ Fix health problems
    </a>
    <a href="?page=<?php echo esc_attr( $_REQUEST['page'] ); ?>&tab=api_config" class="nav-tab <?php echo $current_tab === 'api_config' ? 'nav-tab-active' : ''; ?>">
        🔑 API key
    </a>
    <a href="?page=<?php echo esc_attr( $_REQUEST['page'] ); ?>&tab=fixes_overview" class="nav-tab <?php echo $current_tab === 'fixes_overview' ? 'nav-tab-active' : ''; ?>">
        ✅ Fixes
    </a>
    <a href="?page=<?php echo esc_attr( $_REQUEST['page'] ); ?>&tab=data_management" class="nav-tab <?php echo $current_tab === 'data_management' ? 'nav-tab-active' : ''; ?>">
    ⚙️ Settings
    </a>
    <div class="nav-tab-spinner"></div>
    <div class="rank-experimental-label" data-tooltip="This is an early release. Expect a few rough edges and slowdowns. Share feedback in our chat, captain! 🧑‍🚀👍️">Beta</div>
</h2>
<?php // --- End Tab Navigation --- ?>

<div class="tab-content">
    <div class="tab-content-loader"></div>

        <?php // --- Bulk Fix Tab Content --- ?>
        <?php if ( $current_tab === 'bulk_fix' ) : ?>
            
            <?php if ($is_api_key_set): ?>
                <div class="rank-section">
                    
                    <div id="rank-global-credit-status" style="margin-bottom: 15px; font-weight: bold;"></div>
                    
                    <div id="rank-health-issues-container" style="display:none;">
                        <h2>Fix health problems automatically</h2>
                        <p class="description">Get all pages on your website fixed automatically for each health problem found in your Morningscore account.</p>
                        
                        <div id="rank-health-issues-loading" style="margin-top: 20px;float:left;">
                            <p>Scanning for health issues. This may take a few seconds...</p>
                            <div class="spinner is-active" style="float:none;"></div>
                        </div>
                        
                        <?php
                        // Health issues will be populated by AJAX
                        ?>
                    </div>
                    
                    <div id="rank-processing-area" style="display:none;">
                        <input type="hidden" id="rank-batch-id" value="">
                        <input type="hidden" id="rank-selected-issue-type" value="">
                        
                        <div id="rank-status-container">
                            <p id="rank-status-message">Ready to process...</p>
                            <div id="rank-progress-bar-container" class="rank-progress-container" style="display:none;">
                                <div id="rank-progress-bar" class="rank-progress-bar" style="width: 0%;">0%</div>
                            </div>
                            <h3 id="rank-counts"></h3>
                        </div>
                        
                        <div id="rank-approval-area" style="margin-bottom: 15px;">
                            <?php // Approval items will be loaded here by JavaScript ?>
                        </div>
                        
                        <div class="rank-buttons-container">
                            <button id="rank-start-button" class="button button-primary" style="display:none;">Manual</button>
                            <button id="rank-auto-process-button" class="button button-secondary" style="display:none; float:right;">Automatic</button>
                        </div>
                        
                        <div class="rank-log-container" style="display:none;">
                            <h3>Processing log<div id="rank-log-spinner" class="spinner" style="float:none; display:none;"></div></h3>
                            <div id="rank-log-output" class="rank-log"></div>
                        </div>
                        
                        <div class="rank-cancel-container">
                            <button id="rank-cancel-button" class="button">Cancel</button>
                        </div>
                    </div>
                </div>
                    
                </div>
            <?php endif; ?>
        <?php endif; ?>
        <?php // --- End Bulk Fix Tab Content --- ?>


        <?php // --- API Configuration Tab Content --- ?>
        <?php if ( $current_tab === 'api_config' ) : ?>
            <div class="rank-section">
                <h2>🔑 API key</h2>
                <form id="rank-api-key-form" method="post" action="options.php">
                    <?php settings_fields( 'rank_options_group' ); ?>
                    <?php do_settings_sections( 'rank_options_group' ); ?>
                    <table class="form-table">
                        <tr valign="top">
                            <th scope="row">Morningscore API Key</th>
                            <td>
                                <input type="text" id="rank_api_key" name="rank_api_key" value="<?php echo esc_attr( $api_key ); ?>" size="50" />
                                <p class="description">Enter your API key from Morningscore.</p>
                                <?php if ($is_api_key_set): ?>
                                    <p style="color: green;">API Key is set. Now you can <a href="?page=<?php echo esc_attr( $_REQUEST['page'] ); ?>&tab=bulk_fix">fix health problems</a></p>
                                <?php else: ?>
                                    <p style="color: red;">API Key is not set. Please enter your key.</p>
                                <?php endif; ?>
                            </td>
                        </tr>
                    </table>
                    <?php submit_button('Save API Key'); ?>
                    <div style="margin-top: 100px;">
                        <h3>Find the API key here:</h3>
                       <p> <button
  type="button"
  class="button button-secondary"
  onclick="window.open('https://v3.morningscore.io/settings/api','_blank')"
>
  Direct link to API settings page
</button></p>
                        <img src="<?php echo esc_url( plugins_url( 'get-api-key-morningscore.png', __FILE__ ) ); ?>" alt="How to get your Morningscore API Key" style="max-width: 100%; height: auto; border: 1px solid #c1c1c1; width: 70%;">
                    </div>
                </form>
            </div>
        <?php endif; ?>
        <?php // --- End API Configuration Tab Content --- ?>

        <?php // --- Fixes Overview Tab Content --- ?>
        <?php if ( $current_tab === 'fixes_overview' ) : ?>
            <div class="rank-section">
                <h2>View and edit applied Fixes</h2>
                <p>Expand by clicking on each to see and edit the changes applied by RANK AI.</p>

                <div id="rank-fixes-accordion">
                    <?php foreach ( $health_check_categories as $key => $label ) :
                        // Map the category keys for broken links to match the option names
                        $category_key = $key;
                        if ($key === 'broken_internal_links') {
                            $category_key = 'broken_links_internal';
                        } elseif ($key === 'broken_external_links') {
                            $category_key = 'broken_links_external';
                        }
                    ?>
                        <div class="rank-accordion-item">
                            <button type="button" class="rank-accordion-header" data-category="<?php echo esc_attr( $category_key ); ?>" data-issue-type="<?php echo esc_attr( $key ); ?>">
                                <span><?php echo esc_html( $label ); ?></span>
                                <span class="rank-accordion-meta">
                                    <span class="rank-accordion-count">✅ (...)</span> <?php // Show (...) initially ?>
                                    <span class="rank-accordion-toggle dashicons dashicons-arrow-down-alt2"></span>
                                </span>
                            </button>
                            <div class="rank-accordion-content" style="display: none;">
                                <div class="rank-accordion-table-container">
                                    <?php // Table will be loaded here via AJAX ?>
                                    <p class="rank-accordion-loading" style="display: none;">Loading... 5-15 seconds</p>
                                    <p class="rank-accordion-no-data" style="display: none;">No fixes found for this category.</p>
                                </div>
                                <div class="rank-accordion-pagination">
                                    <?php // Pagination controls will be loaded here ?>
                                </div>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>
        <?php endif; ?>
        <?php // --- End Fixes Overview Tab Content --- ?>


        <?php // --- Data Management Tab Content --- ?>
        <?php if ( $current_tab === 'data_management' ) : ?>
            <div class="rank-section rank-danger-zone">
                <h2>Settings</h2>
                <p><strong>Warning:</strong> This action will permanently delete all SEO overrides (titles, alt tags, etc.) created by RANK AI from your database. This cannot be undone.</p>
                <button type="button" id="rank-show-delete-confirm" class="button button-secondary">Delete All RANK AI Changes</button>

                <div id="rank-delete-confirmation-area" style="display: none; margin-top: 15px; padding: 15px; border: 1px solid #dc3232; background-color: #fef7f7;">
                    <p>To confirm deletion, please type "<strong>DELETE</strong>" into the box below and click the confirm button.</p>
                    <label for="rank-delete-confirm-input">Confirmation:</label>
                    <input type="text" id="rank-delete-confirm-input" name="rank_delete_confirm_input" size="20" />
                    <button type="button" id="rank-confirm-delete-button" class="button button-danger" disabled>Confirm Deletion</button>
                    <p id="rank-delete-status" style="margin-top: 10px;"></p>
                </div>
            </div>
        <?php endif; ?>
        <?php // --- End Data Management Tab Content --- ?>

</div> <?php // end .tab-content ?>

<div style="text-align: left; margin: 20px 0;"> <?php // Added container for centering ?>
    <a href="https://morningscore.io" target="_blank"><img src="<?php echo esc_url( plugins_url( 'Rank.webp', __FILE__ ) ); ?>" alt="RANK AI Logo" width="200"></a>
</div> <?php // Close the wrap div ?>

<?php
// Add debug information if debugging is enabled
if (defined('RANK_DEBUG') && RANK_DEBUG) {
    echo '<div class="rank-debug-section" style="margin-top: 30px; padding: 20px; border: 1px solid #ccc; background-color: #f9f9f9;">';
    echo '<h2>Debug Information</h2>';
    echo '<p>Performance monitoring is enabled. <a href="' . esc_url(plugins_url('debug.php', dirname(__FILE__))) . '" target="_blank">View detailed logs</a></p>';
    echo Rank_Debug::get_html_report();
    echo '</div>';
}
?>