/**
 * API Key Notice Module
 * Ensures the API key notice is displayed when needed
 */
(function($, rank) {
    'use strict';
    
    // Function to add the API key notice
    function addApiKeyNotice() {
        // Check if we're on the bulk_fix tab
        const urlParams = new URLSearchParams(window.location.search);
        const currentTab = urlParams.get('tab') || 'bulk_fix'; // Default to bulk_fix if no tab specified
        
        if (currentTab !== 'bulk_fix') {
            return; // Only show notice on the bulk_fix tab
        }
        
        // Check if the API key is set (using the data attribute on the .wrap div)
        const isApiKeySet = $('.wrap').data('api-key-set') === 'yes';
        
        if (!isApiKeySet) {
            // Get the current URL and replace or add the tab parameter
            const currentUrl = new URL(window.location.href);
            currentUrl.searchParams.set('tab', 'api_config');
            
            // Create the notice with a link to the API config tab
            const $notice = $('<div class="notice notice-warning" style="display: block !important; margin-top: 10px;">' +
                '<p><a href="' + currentUrl.toString() + '">Add API key in settings</a> to start fixing issues 🚀</p>' +
                '</div>');
            
            // Insert it after the tab navigation
            $('.nav-tab-wrapper').after($notice);
        }
    }
    
    // Run when the document is ready
    $(document).ready(function() {
        // Add a small delay to ensure other scripts have run
        setTimeout(addApiKeyNotice, 100);
    });
    
})(jQuery, window.rank = window.rank || {});